@@ -2,7 +2,10 @@ import nwborglab
 import os
 from os.path import expanduser
 from datetime import datetime as dt
-from SAPOFTO import SAPOFTO
+from SAPOFTO import SAPOFTO, recursiveFolderWrite, recursiveFolderRead
+from pynwb import NWBHDF5IO
+
+
 
 def init(args):
     # print ascii art
@@ -46,6 +49,22 @@ def init(args):
 
        		   		   v0.0.1""")
     
+    if len(args) > 0:
+        print('attempting nwborglab initialization from file')
+        if not os.isfile(args[0]) :
+            print(args[0] + ' no such file :(')
+        if not args[0].endswith('.nwb'):
+            io = NWBHDF5IO(args[0], 'r')
+
+        print(nwbfile_in.get_scratch('nwborglab_sensors'))
+        sensors_sapofto = SAPOFTO('sensors',nwbfile_in.get_scratch('nwborglab_sensors'), case_sensitive=True)
+        overview_sapofto = SAPOFTO('OVERVIEW',nwbfile_in.get_scratch('nwborglab_overview'))
+        session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_skeleton')
+        session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
+        
+        recursiveFolderWrite(os.getcwd())
+        return
+    
     tab = '    '
     half_tab = '  '
 
